##  Step-by-Step Guide
  * [Step 1: Understand Your Strategy](https://help.sap.com/docs/leanix/ea/application-modernization-understand-strategy?locale=en-US&state=PRODUCTION&version=CLOUD "Get clear on what modernization means for your organization to guide decisions and priorities during transformation initiatives.")
  * [Step 2: Scope Applications](https://help.sap.com/docs/leanix/ea/application-modernization-scope-applications?locale=en-US&state=PRODUCTION&version=CLOUD "A strategic approach to identifying applications suitable for transformation can optimize resources and enhance operational efficiency.")
  * [Step 3: Collect Data](https://help.sap.com/docs/leanix/ea/application-modernization-collect-data?locale=en-US&state=PRODUCTION&version=CLOUD "Data collection is crucial for getting comprehensive insights into your architecture. You can expedite the process with surveys and integrations.")
  * [Step 4: Evaluate Data](https://help.sap.com/docs/leanix/ea/application-modernization-evaluate-data?locale=en-US&state=PRODUCTION&version=CLOUD "Determine which applications to focus on first as part of your modernization initiative.")
  * [Step 5: Plan Transformations and Create a Roadmap](https://help.sap.com/docs/leanix/ea/application-modernization-transformations-and-roadmap?locale=en-US&state=PRODUCTION&version=CLOUD "After evaluating which applications are best suited for modernization, it's time to plan your initiatives. This involves documenting your decisions, setting up your transformations, and creating a roadmap.")
  * [Step 6: Start Modernization](https://help.sap.com/docs/leanix/ea/application-modernization-start-initiative?locale=en-US&state=PRODUCTION&version=CLOUD "Visualize and evaluate target architecture to help identify impacted applications and necessary technical changes.")
  * [Step 7: Track and Report](https://help.sap.com/docs/leanix/ea/application-modernization-track-report?locale=en-US&state=PRODUCTION&version=CLOUD "Use dashboards to track progress and keep your stakeholders up to date.")


YesNo
Send
Help us provide a better digital experience for you and all other visitors.
What is the purpose of your visit to our website today?
  * Understand software features and benefits for a possible purchase
  * Find information about how to use the software
  * Find implementation or configuration information
  * Find information on installing or upgrading the software
  * Find information to troubleshoot and resolve issues that I'm encountering
  * Find developer or API information
  * Learn about new or updated product features
  * Other (please specify)


You can write a maximum of 255 characters.
Were you able to complete your task?
  * Yes
  * No


Why were you not able to complete your task today?
You can write a maximum of 4000 characters.
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
